@@ -22,8 +22,11 @@
 
 #include <QtDeclarative/qdeclarative.h>
 
+#include <action.h>
+#include <actionmanager.h>
 #include <helpmenuactions.h>
 #include <icondialog.h>
+#include <image.h>
 #include <messagebox.h>
 #include <shadoweffect.h>
 #include <sourceregistry.h>
@@ -32,9 +35,12 @@
 void ComponentsPlugin::registerTypes(const char *uri)
 {
     Q_ASSERT(uri == QLatin1String("org.kde.homerun.components"));
+    qmlRegisterType<Action>(uri, 0, 1, "Action");
+    qmlRegisterType<ActionManager>(uri, 0, 1, "ActionManager");
     qmlRegisterType<ShadowEffect>(uri, 0, 1, "ShadowEffect");
     qmlRegisterType<HelpMenuActions>(uri, 0, 1, "HelpMenuActions");
     qmlRegisterType<IconDialog>(uri, 0, 1, "IconDialog");
+    qmlRegisterType<Image>(uri, 0, 1, "Image");
     qmlRegisterType<MessageBox>(uri, 0, 1, "MessageBox");
     qmlRegisterType<Homerun::AbstractSourceRegistry>(uri, 0, 1, "AbstractSourceRegistry");
     qmlRegisterType<Homerun::SourceRegistry>(uri, 0, 1, "SourceRegistry");
